@@ -151,9 +151,7 @@ import shutil
 import subprocess
 import sys
 import tempfile
-import warnings
 
-import numpy
 from packaging.version import parse as parse_version
 
 # cbook must import matplotlib only within function
@@ -161,7 +159,8 @@ from packaging.version import parse as parse_version
 from . import _api, _version, cbook, _docstring, rcsetup
 from matplotlib.cbook import sanitize_sequence
 from matplotlib._api import MatplotlibDeprecationWarning
-from matplotlib.rcsetup import validate_backend, cycler
+from matplotlib.rcsetup import cycler  # noqa: F401
+from matplotlib.rcsetup import validate_backend
 
 
 _log = logging.getLogger(__name__)
@@ -219,15 +218,20 @@ def _get_version():
     if ((root / ".matplotlib-repo").exists()
             and (root / ".git").exists()
             and not (root / ".git/shallow").exists()):
-        import setuptools_scm
-        return setuptools_scm.get_version(
-            root=root,
-            version_scheme="release-branch-semver",
-            local_scheme="node-and-date",
-            fallback_version=_version.version,
-        )
-    else:  # Get the version from the _version.py setuptools_scm file.
-        return _version.version
+        try:
+            import setuptools_scm
+        except ImportError:
+            pass
+        else:
+            return setuptools_scm.get_version(
+                root=root,
+                version_scheme="release-branch-semver",
+                local_scheme="node-and-date",
+                fallback_version=_version.version,
+            )
+    # Get the version from the _version.py file if not in repo or setuptools_scm is
+    # unavailable.
+    return _version.version
 
 
 @_api.caching_module_getattr
@@ -241,13 +245,13 @@ def _check_versions():
 
     # Quickfix to ensure Microsoft Visual C++ redistributable
     # DLLs are loaded before importing kiwisolver
-    from . import ft2font
+    from . import ft2font  # noqa: F401
 
     for modname, minver in [
             ("cycler", "0.10"),
             ("dateutil", "2.7"),
-            ("kiwisolver", "1.0.1"),
-            ("numpy", "1.21"),
+            ("kiwisolver", "1.3.1"),
+            ("numpy", "1.23"),
             ("pyparsing", "2.3.1"),
     ]:
         module = importlib.import_module(modname)
@@ -1204,7 +1208,7 @@ def use(backend, *, force=True):
         backend names, which are case-insensitive:
 
         - interactive backends:
-          GTK3Agg, GTK3Cairo, GTK4Agg, GTK4Cairo, MacOSX, nbAgg, QtAgg,
+          GTK3Agg, GTK3Cairo, GTK4Agg, GTK4Cairo, MacOSX, nbAgg, notebook, QtAgg,
           QtCairo, TkAgg, TkCairo, WebAgg, WX, WXAgg, WXCairo, Qt5Agg, Qt5Cairo
 
         - non-interactive backends:
@@ -1212,6 +1216,8 @@ def use(backend, *, force=True):
 
         or a string of the form: ``module://my.module.name``.
 
+        notebook is a synonym for nbAgg.
+
         Switching to an interactive backend is not possible if an unrelated
         event loop has already been started (e.g., switching to GTK3Agg if a
         TkAgg window has already been opened).  Switching to a non-interactive
@@ -1302,21 +1308,23 @@ def _val_or_rc(val, rc_name):
 
 
 def _init_tests():
-    # The version of FreeType to install locally for running the
-    # tests.  This must match the value in `setupext.py`
-    LOCAL_FREETYPE_VERSION = '2.12.1'
+    # The version of FreeType to install locally for running the tests. This must match
+    # the value in `meson.build`.
+    LOCAL_FREETYPE_VERSION = '2.13.1'
 
     from matplotlib import ft2font
     if (ft2font.__freetype_version__ != LOCAL_FREETYPE_VERSION or
             ft2font.__freetype_build_type__ != 'local'):
         _log.warning(
-            f"Matplotlib is not built with the correct FreeType version to "
-            f"run tests.  Rebuild without setting system_freetype=1 in "
-            f"mplsetup.cfg.  Expect many image comparison failures below.  "
-            f"Expected freetype version {LOCAL_FREETYPE_VERSION}.  "
-            f"Found freetype version {ft2font.__freetype_version__}.  "
-            "Freetype build type is {}local".format(
-                "" if ft2font.__freetype_build_type__ == 'local' else "not "))
+            "Matplotlib is not built with the correct FreeType version to run tests.  "
+            "Rebuild without setting system-freetype=true in Meson setup options.  "
+            "Expect many image comparison failures below.  "
+            "Expected freetype version %s.  "
+            "Found freetype version %s.  "
+            "Freetype build type is %slocal.",
+            LOCAL_FREETYPE_VERSION,
+            ft2font.__freetype_version__,
+            "" if ft2font.__freetype_build_type__ == 'local' else "not ")
 
 
 def _replacer(data, value):
@@ -1462,7 +1470,10 @@ def _preprocess_data(func=None, *, replace_names=None, label_namer=None):
     @functools.wraps(func)
     def inner(ax, *args, data=None, **kwargs):
         if data is None:
-            return func(ax, *map(sanitize_sequence, args), **kwargs)
+            return func(
+                ax,
+                *map(sanitize_sequence, args),
+                **{k: sanitize_sequence(v) for k, v in kwargs.items()})
 
         bound = new_sig.bind(ax, *args, **kwargs)
         auto_label = (bound.arguments.get(label_namer)
@@ -1501,5 +1512,5 @@ _log.debug('platform is %s', sys.platform)
 
 # workaround: we must defer colormaps import to after loading rcParams, because
 # colormap creation depends on rcParams
-from matplotlib.cm import _colormaps as colormaps
-from matplotlib.colors import _color_sequences as color_sequences
+from matplotlib.cm import _colormaps as colormaps  # noqa: E402
+from matplotlib.colors import _color_sequences as color_sequences  # noqa: E402
