@@ -7,8 +7,7 @@ the grid are referenced by `SubplotSpec`\s.
 
 Often, users need not access this module directly, and can use higher-level
 methods like `~.pyplot.subplots`, `~.pyplot.subplot_mosaic` and
-`~.Figure.subfigures`. See the tutorial
-:doc:`/tutorials/intermediate/arranging_axes` for a guide.
+`~.Figure.subfigures`. See the tutorial :ref:`arranging_axes` for a guide.
 """
 
 import copy
@@ -56,9 +55,9 @@ class GridSpecBase:
         self.set_width_ratios(width_ratios)
 
     def __repr__(self):
-        height_arg = (', height_ratios=%r' % (self._row_height_ratios,)
+        height_arg = (f', height_ratios={self._row_height_ratios!r}'
                       if len(set(self._row_height_ratios)) != 1 else '')
-        width_arg = (', width_ratios=%r' % (self._col_width_ratios,)
+        width_arg = (f', width_ratios={self._col_width_ratios!r}'
                      if len(set(self._col_width_ratios)) != 1 else '')
         return '{clsname}({nrows}, {ncols}{optionals})'.format(
             clsname=self.__class__.__name__,
@@ -142,8 +141,7 @@ class GridSpecBase:
         """
         return self._row_height_ratios
 
-    @_api.delete_parameter("3.7", "raw")
-    def get_grid_positions(self, fig, raw=False):
+    def get_grid_positions(self, fig):
         """
         Return the positions of the grid cells in figure coordinates.
 
@@ -152,11 +150,6 @@ class GridSpecBase:
         fig : `~matplotlib.figure.Figure`
             The figure the grid should be applied to. The subplot parameters
             (margins and spacing between subplots) are taken from *fig*.
-        raw : bool, default: False
-            If *True*, the subplot parameters of the figure are not taken
-            into account. The grid spans the range [0, 1] in both directions
-            without margins and there is no space between grid cells. This is
-            used for constrained_layout.
 
         Returns
         -------
@@ -165,22 +158,13 @@ class GridSpecBase:
             figure coordinates.
         """
         nrows, ncols = self.get_geometry()
-
-        if raw:
-            left = 0.
-            right = 1.
-            bottom = 0.
-            top = 1.
-            wspace = 0.
-            hspace = 0.
-        else:
-            subplot_params = self.get_subplot_params(fig)
-            left = subplot_params.left
-            right = subplot_params.right
-            bottom = subplot_params.bottom
-            top = subplot_params.top
-            wspace = subplot_params.wspace
-            hspace = subplot_params.hspace
+        subplot_params = self.get_subplot_params(fig)
+        left = subplot_params.left
+        right = subplot_params.right
+        bottom = subplot_params.bottom
+        top = subplot_params.top
+        wspace = subplot_params.wspace
+        hspace = subplot_params.hspace
         tot_width = right - left
         tot_height = top - bottom
 
@@ -288,7 +272,7 @@ class GridSpecBase:
         # don't mutate kwargs passed by user...
         subplot_kw = subplot_kw.copy()
 
-        # Create array to hold all axes.
+        # Create array to hold all Axes.
         axarr = np.empty((self._nrows, self._ncols), dtype=object)
         for row in range(self._nrows):
             for col in range(self._ncols):
@@ -302,10 +286,10 @@ class GridSpecBase:
         # turn off redundant tick labeling
         if sharex in ["col", "all"]:
             for ax in axarr.flat:
-                ax._label_outer_xaxis(check_patch=True)
+                ax._label_outer_xaxis(skip_non_rectangular_axes=True)
         if sharey in ["row", "all"]:
             for ax in axarr.flat:
-                ax._label_outer_yaxis(check_patch=True)
+                ax._label_outer_yaxis(skip_non_rectangular_axes=True)
 
         if squeeze:
             # Discarding unneeded dimensions that equal 1.  If we only have one
@@ -321,7 +305,7 @@ class GridSpec(GridSpecBase):
     A grid layout to place subplots within a figure.
 
     The location of the grid cells is determined in a similar way to
-    `~.figure.SubplotParams` using *left*, *right*, *top*, *bottom*, *wspace*
+    `.SubplotParams` using *left*, *right*, *top*, *bottom*, *wspace*
     and *hspace*.
 
     Indexing a GridSpec instance returns a `.SubplotSpec`.
@@ -419,11 +403,13 @@ class GridSpec(GridSpecBase):
         - non-*None* attributes of the GridSpec
         - the provided *figure*
         - :rc:`figure.subplot.*`
+
+        Note that the ``figure`` attribute of the GridSpec is always ignored.
         """
         if figure is None:
             kw = {k: mpl.rcParams["figure.subplot."+k]
                   for k in self._AllowedKeys}
-            subplotpars = mpl.figure.SubplotParams(**kw)
+            subplotpars = SubplotParams(**kw)
         else:
             subplotpars = copy.copy(figure.subplotpars)
 
@@ -498,7 +484,12 @@ class GridSpecFromSubplotSpec(GridSpecBase):
         """
         self._wspace = wspace
         self._hspace = hspace
-        self._subplot_spec = subplot_spec
+        if isinstance(subplot_spec, SubplotSpec):
+            self._subplot_spec = subplot_spec
+        else:
+            raise TypeError(
+                            "subplot_spec must be type SubplotSpec, "
+                            "usually from GridSpec, or axes.get_subplotspec.")
         self.figure = self._subplot_spec.get_gridspec().figure
         super().__init__(nrows, ncols,
                          width_ratios=width_ratios,
@@ -516,9 +507,9 @@ class GridSpecFromSubplotSpec(GridSpecBase):
         figbox = self._subplot_spec.get_position(figure)
         left, bottom, right, top = figbox.extents
 
-        return mpl.figure.SubplotParams(left=left, right=right,
-                                        bottom=bottom, top=top,
-                                        wspace=wspace, hspace=hspace)
+        return SubplotParams(left=left, right=right,
+                             bottom=bottom, top=top,
+                             wspace=wspace, hspace=hspace)
 
     def get_topmost_subplotspec(self):
         """
@@ -735,3 +726,63 @@ class SubplotSpec:
                 fig.add_subplot(gssub[0, i])
         """
         return GridSpecFromSubplotSpec(nrows, ncols, self, **kwargs)
+
+
+class SubplotParams:
+    """
+    Parameters defining the positioning of a subplots grid in a figure.
+    """
+
+    def __init__(self, left=None, bottom=None, right=None, top=None,
+                 wspace=None, hspace=None):
+        """
+        Defaults are given by :rc:`figure.subplot.[name]`.
+
+        Parameters
+        ----------
+        left : float
+            The position of the left edge of the subplots,
+            as a fraction of the figure width.
+        right : float
+            The position of the right edge of the subplots,
+            as a fraction of the figure width.
+        bottom : float
+            The position of the bottom edge of the subplots,
+            as a fraction of the figure height.
+        top : float
+            The position of the top edge of the subplots,
+            as a fraction of the figure height.
+        wspace : float
+            The width of the padding between subplots,
+            as a fraction of the average Axes width.
+        hspace : float
+            The height of the padding between subplots,
+            as a fraction of the average Axes height.
+        """
+        for key in ["left", "bottom", "right", "top", "wspace", "hspace"]:
+            setattr(self, key, mpl.rcParams[f"figure.subplot.{key}"])
+        self.update(left, bottom, right, top, wspace, hspace)
+
+    def update(self, left=None, bottom=None, right=None, top=None,
+               wspace=None, hspace=None):
+        """
+        Update the dimensions of the passed parameters. *None* means unchanged.
+        """
+        if ((left if left is not None else self.left)
+                >= (right if right is not None else self.right)):
+            raise ValueError('left cannot be >= right')
+        if ((bottom if bottom is not None else self.bottom)
+                >= (top if top is not None else self.top)):
+            raise ValueError('bottom cannot be >= top')
+        if left is not None:
+            self.left = left
+        if right is not None:
+            self.right = right
+        if bottom is not None:
+            self.bottom = bottom
+        if top is not None:
+            self.top = top
+        if wspace is not None:
+            self.wspace = wspace
+        if hspace is not None:
+            self.hspace = hspace
